//
//  Fraction.m
//  FractionPicker
//
//  Created by Terry Payne on 06/06/2011.
//  Copyright 2011 University of Liverpool. All rights reserved.
//

#import "Fraction.h"


@implementation Fraction

- (void) setNumerator: (int) n {
    numerator = n;
}

- (void) setDenominator: (int) d {
    denominator = d;
}

- (int) numerator {
    return numerator;
}

- (int) denominator {
    return denominator;
}

- (void) setTo: (int) n over: (int) d {
    denominator = d;
    numerator = n;
}

- (double) convertToNum {
    if (denominator != 0)
        return (double) numerator / denominator;
    else
        return 1.0;
}

- (NSString *) convertToString {
    
    // Start by checking if the numerator is greater than the denominator - if
    // so, then we want to include a number and generate the remainder as a fraction.

    // Start by creating a new string.  We want to maintain ownership... for now!
    NSString *myStr = [NSString alloc];
    
    if (numerator >= denominator) {
        if ((numerator % denominator) != 0) {
            myStr = [myStr initWithFormat:@"%d %d/%d",
                     (numerator / denominator), (numerator % denominator), denominator];
        } else {
            myStr = [myStr initWithFormat:@"%d", (numerator / denominator)];
        }
    } else {
        myStr = [myStr initWithFormat:@"%d/%d", numerator, denominator];
    }
    
    // However, we do't want the caller to worry about ownership, so lets autorelease
    // the string for now - this will be clearer later in the module
    [myStr autorelease];
    return myStr;
}

- (void) reduce {
    int u = numerator;
    int v = denominator;
    int temp;
    
    while (v!=0) {
        temp = u%v;
        u=v;
        v=temp;
    }
    numerator /= u;
    denominator /= u;
}

- (void) add: (Fraction *)f {
    numerator = (numerator * [f denominator]) + (denominator * [f numerator]);
    denominator = denominator * [f denominator];
    
    [self reduce];
}

@end
