//
//  FractionPickerViewController.m
//  FractionPicker
//
//  Created by Terry Payne on 06/06/2011.
//  Copyright 2011 University of Liverpool. All rights reserved.
//

#import "FractionPickerViewController.h"

@implementation FractionPickerViewController

@synthesize fraction1PickerView;
@synthesize fraction2PickerView;
@synthesize fractionLabel;
@synthesize showFractionButton;

- (IBAction)fractionButtonPressed:(id)sender{

    [myAddedFraction setTo:[myFraction1 numerator] over:[myFraction1 denominator]];
    [myAddedFraction add:myFraction2];
    
    NSString *msgStr = [NSString stringWithFormat:@"%@ = %f",
                       [myAddedFraction convertToString],
                       [myAddedFraction convertToNum]];

    UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Add Fractions"
                                                    message:msgStr
                                                   delegate:self
                                          cancelButtonTitle:@"Done"
                                          otherButtonTitles: nil];
    [alert show];
    [alert release];
}


// ======================================================================
#pragma mark - UIPickerViewDelegate methods
// ======================================================================


- (void)pickerView:(UIPickerView *)pickerView didSelectRow:(NSInteger)row inComponent:(NSInteger)component
{
    // Don't care which component changed value.
    // Just update the presentation of the fraction in terms of numerator and denominator
    // As the range is 1-MAX_NUMBER_ON_PICKER, we add 1 to the row
    
    NSInteger myNumerator = 1+[pickerView selectedRowInComponent:NUMERATOR];
    NSInteger myDenominator = 1+[pickerView selectedRowInComponent:DENOMINATOR];
    
    // This could be written more elegantly
    if (pickerView == fraction1PickerView) {
        // Fraction 1 picker called this method
        [myFraction1 setTo:myNumerator over:myDenominator];
    } else {
        // Fraction 2 picker called this method
        [myFraction2 setTo:myNumerator over:myDenominator];
    }
    
    [self updateFractionLabel];
}

- (void)updateFractionLabel {
    NSString *fractionStr = [NSString stringWithFormat:@"%@ + %@ = ???",
                             [myFraction1 convertToString], [myFraction2 convertToString]];
                             
                             
    [fractionLabel setText:fractionStr];
}

- (NSString *)pickerView:(UIPickerView *)pickerView titleForRow:(NSInteger)row forComponent:(NSInteger)component
{
    // Both pickers just display numbers from 1 to 9
    return [NSString stringWithFormat:@"%d", 1+row];
}

// ======================================================================
#pragma mark - UIPickerViewDataSource methods
// ======================================================================

// Returns the number of components (or “columns”) that the picker view should display.
- (NSInteger)numberOfComponentsInPickerView:(UIPickerView *)pickerView
{
    // Ignore the value of pickerView, as we assume only one picker for now
    return NUMBER_OF_PICKER_COMPONENTS;
}

// Returns the number of rows for the component.
- (NSInteger)pickerView:(UIPickerView *)pickerView numberOfRowsInComponent:(NSInteger)component
{
    // Ignore the value of pickerView, as we assume only one picker for now
    return MAX_NUMBER_ON_PICKER;
}

// ======================================================================
#pragma mark - UIPicker Other Methods
// ======================================================================



// ======================================================================
#pragma mark - Memory Management
// ======================================================================

- (void)dealloc
{
    [myFraction1 release];
    [myFraction2 release];
    [super dealloc];
}

- (void)didReceiveMemoryWarning
{
    // Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
    
    // Release any cached data, images, etc that aren't in use.
}

// ======================================================================
#pragma mark - View lifecycle
// ======================================================================


// Implement viewDidLoad to do additional setup after loading the view, typically from a nib.
- (void)viewDidLoad
{
    [super viewDidLoad];

    myFraction1 = [[Fraction alloc] init];
    [myFraction1 setTo:1 over:1];
    
    myFraction2 = [[Fraction alloc] init];
    [myFraction2 setTo:1 over:1];

    myAddedFraction = [[Fraction alloc] init];
    [myAddedFraction setTo:0 over:0];

    [self updateFractionLabel];
}


- (void)viewDidUnload
{
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    // e.g. self.myOutlet = nil;
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    // Return YES for supported orientations
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}

@end
